@@ -1,7 +1,7 @@
 // -*- C++ -*-
 //
 // This file is part of LHAPDF
-// Copyright (C) 2012-2019 The LHAPDF collaboration (see AUTHORS for details)
+// Copyright (C) 2012-2021 The LHAPDF collaboration (see AUTHORS for details)
 //
 #pragma once
 #ifndef LHAPDF_BicubicInterpolator_H
@@ -17,7 +17,9 @@ namespace LHAPDF {
   /// This class will interpolate in 2D using a bicubic hermite spline.
   class BicubicInterpolator : public Interpolator {
   public:
-    double _interpolateXQ2(const KnotArray1F& subgrid, double x, size_t ix, double q2, size_t iq2) const;
+    BicubicInterpolator(){ setType("cubic"); }
+    double _interpolateXQ2(const KnotArray& subgrid, double x, size_t ix, double q2, size_t iq2, int id) const;
+    void _interpolateXQ2(const KnotArray& subgrid, double x, size_t ix, double q2, size_t iq2, std::vector<double>& ret) const;
   };
 
 
